@@ -58,7 +58,9 @@ print.DOVE <- function(x, ...) {
   # }
   
   if (!is.null(attr(x = x, which = "dSum"))) {
-    attr(x = x, which = c("tau", "dSum", "type")) <- NULL
+    attr(x = x, which = "tau") <- NULL
+    attr(x = x, which = "dSum") <- NULL
+    attr(x = x, which = "type") <- NULL
   } else {
     attr(x = x, which = "type") <- NULL
   }
